
% Test loaddods by reading some URLs and comparing the values read in with
% ones stored in a saved work space.
%
% $Id: matlab_tests.m,v 1.2 1999/05/25 21:37:48 jimg Exp $
%

% This file contains data to compare with values read over the network. For
% each of the URLs below, a matching variable with the suffix `_data' is
% contained in this file. Compare <x> to <x>_data to determine if the read
% was successful.

load testsuite/test_loaddods.mat;

base_url = 'http://dods.gso.uri.edu/cgi-bin/nph-';

dsp_1 = [base_url 'dsp/data/east.coast?dsp_band_1[100:105][100:101]'];
loaddods(dsp_1);

if all(dsp_band_1 == dsp_band_1_data) 
   disp ' ';
   disp 'PASS: load byte array';
   disp ' ';
else
   disp ' ';
   disp 'FAIL: load byte array';
   disp ' ';
end

dsp_2 = [base_url 'dsp/data/f96243170857.img?dsp_band_1[100:110][100:100] -r dsp_band_1:gimg -r lat:glat -r lon:glon'];
loaddods(dsp_2);

if all(gimg == gimg_data) & all(glat == glat_data) & all(glon == glon_data)
   disp ' ';
   disp 'PASS: load byte/float grid';
   disp ' ';
else
   disp ' ';
   disp 'FAIL: load byte/float grid';
   disp ' ';
end

fnoc1 = [base_url 'nc/data/fnoc1.nc?u[0:0][0:10][0:1],lat[0:10],time[0:0]'];
loaddods(fnoc1);

if all(u == u_data) & all(lat == lat_data) & all(time == time_data)
   disp ' ';
   disp 'PASS: load multi-varaible float arrays';
   disp ' ';
else
   disp ' ';
   disp 'FAIL: load multi-varaible float arrays';
   disp ' ';
end

fnoc2 = [base_url 'nc/data/fnoc1.nc?u[0:0][0:10][0:1] -r u:u_cat ' base_url 'nc/data/fnoc1.nc?u[1:1][0:10][0:1] -r u:u_cat'];
loaddods('-k', fnoc2);

if all(u_cat == u_cat_data)
   disp ' ';
   disp 'PASS: cat float arrays';
   disp ' ';
else
   disp ' ';
   disp 'FAIL: cat float arrays';
   disp ' ';
end

jg1 = [base_url 'jg/bot?cast,sta,depth,ctdtemp&depth<4'];
loaddods('-F', jg1);

if all(cast == cast_data) & all(sta == sta_data) & all(depth(1:14) == depth_data(1:14)) & all(depth(27:52) == depth_data(27:52)) & all(ctdtemp(1:14) == ctdtemp_data(1:14)) & all(ctdtemp(27:52) == ctdtemp_data(27:52))
   disp ' ';
   disp 'PASS: load Sequence of String with value translation';
   disp ' ';
else
   disp ' ';
   disp 'FAIL: load Sequence of String with value translation';
   disp ' ';
end
